/*Set name of log-file and make it empty before start*/
FILENAME mylog 'C:\My\teksten\MIMS2009\DataFS\ProgManip\AgeLabmExperience_Ext.log';
FILENAME myout 'C:\My\teksten\MIMS2009\DataFS\ProgManip\AgeLabmExperience.txt';
DATA _NULL_; 
    FILE mylog;
RUN;
DATA _NULL_; 
    FILE myout;
RUN;
PROC PRINTTO LOG=mylog PRINT=myout;
RUN;

DM 'Log; CLEAR; Output; Clear; ';

/*Create a data set with the first year for which there are assimilated days*/
LIBNAME LIBW    'C:\My\teksten\MIMS2009\DataFS\MANIP\';

%Macro VoerUit;
    /*Set data set*/
    DATA Samen;
        SET 
        LIBW.careerinfo
        LIBW.careerinfo_since2002
        ;
    RUN;
    /*sorteer op individueel nummer en per prestatiejaar*/
    PROC SORT Data=Samen;
        BY gecodeerd_insz annee_prest;
    RUN;
    PROC PRINT DATA=Samen(obs=100);
    RUN;
    /*Identify the first year for which assimilated days are observed*/ 
    DATA PerIndiv;

        SET Samen;
        BY gecodeerd_insz annee_prest;

        RETAIN ASSIMYEAR 0;

        IF first.gecodeerd_insz THEN DO;
            /*identify year in the first line only if assimilated days are observed*/
            IF ASSIMDAYS NE 0 AND ASSIMDAYS NE . THEN DO;
                ASSIMYEAR = annee_prest ;
            END;    
            ELSE DO;
                ASSIMYEAR = 0;
            END;
        END;
        ELSE DO;
            /*identify year in the next lines only if assimilated days are observed and the year is not identified yet*/
            IF ASSIMDAYS NE 0 AND ASSIMDAYS NE . AND ASSIMYEAR EQ 0 THEN DO;
                ASSIMYEAR = annee_prest ;
            END;    
        END;        
        IF last.gecodeerd_insz THEN OUTPUT;
    RUN;
    /*keep constructed variables*/
    DATA PerIndivAssim;
        SET PerIndiv(keep = gecodeerd_insz ASSIMYEAR);
        BY gecodeerd_insz;
    RUN;
    PROC PRINT DATA=PerIndiv(obs=100);
    RUN;
%Mend VoerUit;
%VoerUit;
/*Create a data set with the first year for which there are remunerated days of work*/
%Macro VoerUit;
    /*Set data set*/
    DATA Samen;
        SET 
        LIBW.careerinfo
        LIBW.careerinfo_since2002
        ;
    RUN;
    /*sorteer op individueel nummer en per prestatiejaar*/
    PROC SORT Data=Samen;
        BY gecodeerd_insz annee_prest;
    RUN;
    PROC PRINT DATA=Samen(obs=100);
    RUN;
    /*Identify the first year for which there are remunerated days of work*/ 
    DATA PerIndiv;

        SET Samen;
        BY gecodeerd_insz annee_prest;

        RETAIN WORKYEAR WORKYEAR_SIGNIF 0;

        IF first.gecodeerd_insz THEN DO;
            /*identify year in the first line only if remunerated days of work are observed*/
            IF REMDAYS NE 0 AND REMDAYS NE . THEN DO;
                WORKYEAR = annee_prest ;
            END;    
            ELSE DO;
                WORKYEAR = 0;
            END;
            /*identify year in the first line only if a significant amount of remunerated days of work are observed*/
            /*value chosen here is: (52*5*7.6)*1/3. Rule of 1/3 comes from the fact that you start to build up pension rights from 1/3 of a full career year*/
            IF REMHOURS NE 0 AND REMHOURS NE . AND REMHOURS GT 659 THEN DO;
                WORKYEAR_SIGNIF = annee_prest ;
            END;    
            ELSE DO;
                WORKYEAR_SIGNIF = 0;
            END;
        END;
        ELSE DO;
            /*identify year in the next lines only if remunerated days of work are observed and the year is not identified yet*/
            IF REMDAYS NE 0 AND REMDAYS NE . AND WORKYEAR EQ 0 THEN DO;
                WORKYEAR = annee_prest ;
            END;    
            /*identify year in the first line only if a significant amount of remunerated days of work are observed*/
            /*value chosen here is: (52*5*7.6)*1/3. Rule of 1/3 comes from the fact that you start to build up pension rights from 1/3 of a full career year*/
            IF REMHOURS NE 0 AND REMHOURS NE . AND REMHOURS GT 659 THEN DO;
                WORKYEAR_SIGNIF = annee_prest ;
            END;    
        END;        
        IF last.gecodeerd_insz THEN OUTPUT;
    RUN;
    /*keep constructed variables*/
    DATA PerIndivWork;
        SET PerIndiv(keep = gecodeerd_insz WORKYEAR WORKYEAR_SIGNIF);
        BY gecodeerd_insz;
    RUN;
    PROC PRINT DATA=PerIndiv(obs=100);
    RUN;
%Mend VoerUit;
%VoerUit;
/*Start creation of ages*/
DATA ProbData;
    SET LIBW.POPCHAR_2009(KEEP=GECODEERD_INSZ NAREGNIS_DATBIRTH);
RUN;
PROC SORT DATA=ProbData;
    BY GECODEERD_INSZ;
RUN;
Data LIBW.AgeWORKASSIM;

    MERGE PerIndivAssim PerIndivWork ProbData(in=InA);
    BY gecodeerd_insz;

    IF InA EQ 1;
    
    IF WORKYEAR EQ .            THEN WORKYEAR = 0;
    IF WORKYEAR_SIGNIF EQ .     THEN WORKYEAR_SIGNIF = 0;
    IF ASSIMYEAR EQ .           THEN ASSIMYEAR = 0;

    indexstreepje = INDEX(NAREGNIS_DATBIRTH,'-');
    yearbirth     = INPUT(SUBSTR(NAREGNIS_DATBIRTH,indexstreepje+1,4),8.);
    monthbirth    = INPUT(SUBSTR(NAREGNIS_DATBIRTH,1,indexstreepje-1),8.);
    IF yearbirth  EQ . THEN yearbirth = 0;
    IF monthbirth EQ . THEN monthbirth= 0;

    /*AGE ASSIM*/
    Leeftijd      = FLOOR(((ASSIMYEAR - yearbirth)*12 + monthbirth)/12);
    FIRSTASSIM = 9999999;
    IF NAREGNIS_DATBIRTH NE "99-9999" AND ASSIMYEAR NE 0 THEN FIRSTASSIM = Leeftijd ;
    Label FIRSTASSIM = "Age at which we observe for the first time assimilated days for this individual";

    /*AGE WORK*/
    Leeftijd      = FLOOR(((WORKYEAR - yearbirth)*12 + monthbirth)/12);
    FIRSTWORK = 9999999;
    IF NAREGNIS_DATBIRTH NE "99-9999" AND WORKYEAR NE 0 THEN FIRSTWORK = Leeftijd ;
    Label FIRSTWORK = "Age at which we observe for the first time remunerated days for this individual";

    /*AGE SIGNIFICANT WORK*/
    Leeftijd      = FLOOR(((WORKYEAR_SIGNIF - yearbirth)*12 + monthbirth)/12);
    FIRSTWORK_SIGNIF = 9999999;
    IF NAREGNIS_DATBIRTH NE "99-9999" AND WORKYEAR_SIGNIF NE 0 THEN FIRSTWORK_SIGNIF = Leeftijd ;
    Label FIRSTWORK_SIGNIF = "Age at which we observe for the first time a significant amount of remunerated hours per year for this individual (i.e. more then 659 hours)";

    KEEP gecodeerd_insz FIRSTASSIM FIRSTWORK FIRSTWORK_SIGNIF ;
    
RUN;

PROC CONTENTS DATA=LIBW.AgeWORKASSIM;
RUN;
PROC PRINT DATA=LIBW.AgeWORKASSIM(obs=100);
RUN;
PROC FREQ DATA=LIBW.AgeWORKASSIM;
    TABLES FIRSTASSIM FIRSTWORK FIRSTWORK_SIGNIF ;
RUN;

/*einde programma*/
PROC PRINTTO LOG=LOG PRINT=PRINT;
RUN;
