/*Bepaal log-file en maak file leeg voor volgende run*/
FILENAME mylog 'C:\My\teksten\MIMS2009\DataFS\ProgManip\CreateCareerInfoFrom2002_Ext.log';
FILENAME myout 'C:\My\teksten\MIMS2009\DataFS\ProgManip\CreateCareerInfoFrom2002.txt';
DATA _NULL_; 
    FILE mylog;
RUN;
DATA _NULL_; 
    FILE myout;
RUN;
PROC PRINTTO LOG=mylog PRINT=myout;
RUN;

DM 'Log; CLEAR; Output; Clear; ';

/*Define library with latest version of CIMIRe data*/
LIBNAME LIB     'C:\My\teksten\MIMS2009\DataFS\ORIG\';
LIBNAME LIBW    'C:\My\teksten\MIMS2009\DataFS\MANIP\';

%MACRO ForEach(EEJJ);


    /*Data RSZ*/
    PROC SORT DATA=LIB.mim2008_rszyear_&EEJJ._code;
        BY GECODEERD_INSZ;
    RUN;        
    PROC SORT DATA=LIB.mim2008_labmstatrsz_&EEJJ._code;
        BY GECODEERD_INSZ;
    RUN;        

    DATA RSZ_&EEJJ.;

        MERGE LIB.mim2008_rszyear_&EEJJ._code LIB.mim2008_labmstatrsz_&EEJJ._code;
        BY GECODEERD_INSZ;
        
        IF RSZ_LABMSTAT_PRIV_&EEJJ. EQ . THEN RSZ_LABMSTAT_PRIV_&EEJJ. = 0;
        IF RSZ_LABMSTAT_PUB_&EEJJ.  EQ . THEN RSZ_LABMSTAT_PUB_&EEJJ. = 0;  

        REMDAYS_SUB     = jrsrem_f_&EEJJ. + jrsrem_p_&EEJJ.;
        ASSIMDAYS_SUB   = jrsasm_&EEJJ.;
        REMUN_SUB       = SumSal_&EEJJ.;
        
        %IF &EEJJ. LT 2003 %THEN %DO;
            REMHOURS_SUB    = (jrsrem_f_&EEJJ.)*7.6 + (jrsrem_p_&EEJJ.)*3.8;
        %END;
        %ELSE %DO;
            REMHOURS_SUB    = (jrsrem_f_&EEJJ.)*7.6 + heurpt_&EEJJ.;
        %END;

        IF RSZ_LABMSTAT_PRIV_&EEJJ. EQ 0 AND RSZ_LABMSTAT_PUB_&EEJJ. > 2 THEN DELETE;
        
        KEEP GECODEERD_INSZ REMDAYS_SUB ASSIMDAYS_SUB REMUN_SUB REMHOURS_SUB;
        
    RUN;

    /*Data RSZPPO*/
    PROC SORT DATA=LIB.mim2008_rszppoyear_&EEJJ._code;
        BY GECODEERD_INSZ;
    RUN;        
    PROC SORT DATA=LIB.mim2008_labmstatrszppo_&EEJJ._code;
        BY GECODEERD_INSZ;
    RUN;        

    DATA RSZPPO_&EEJJ.;

        SET LIB.mim2008_rszppoyear_&EEJJ._code LIB.mim2008_labmstatrszppo_&EEJJ._code;
        BY GECODEERD_INSZ;

        IF RSZPPO_LABMSTAT_PUB_&EEJJ.  EQ . THEN RSZPPO_LABMSTAT_PUB_&EEJJ. = 0;  

        REMDAYS_SUB     = RemunDay_&EEJJ.;
        ASSIMDAYS_SUB   = AssimDay_&EEJJ.;
        REMUN_SUB       = SumSal_&EEJJ.;
        REMHOURS_SUB    = RemunHour_&EEJJ.;
        
        IF RSZPPO_LABMSTAT_PUB_&EEJJ. > 2 THEN DELETE;

        KEEP GECODEERD_INSZ REMDAYS_SUB ASSIMDAYS_SUB REMUN_SUB REMHOURS_SUB;

    RUN;

    /*Combineer gegevens*/
    DATA COMBIN_&EEJJ.;
        
        SET 
        RSZ_&EEJJ. 
        RSZPPO_&EEJJ.
        ;

        IF REMDAYS_SUB   EQ . THEN  REMDAYS_SUB   = 0;
        IF ASSIMDAYS_SUB EQ . THEN  ASSIMDAYS_SUB = 0;
        IF REMUN_SUB     EQ . THEN  REMUN_SUB     = 0;
        IF REMHOURS_SUB  EQ . THEN  REMHOURS_SUB  = 0;
        
    RUN;

    /*Voeg gegevens samen in aggregaat op jaarbasis*/
    PROC SQL;
        CREATE TABLE INCLab_&EEJJ. AS
        SELECT GECODEERD_INSZ, SUM(REMDAYS_SUB) AS REMDAYS, SUM(ASSIMDAYS_SUB) AS ASSIMDAYS, SUM(REMUN_SUB) AS REMUN, SUM(REMHOURS_SUB) AS REMHOURS
        FROM COMBIN_&EEJJ.
        GROUP BY GECODEERD_INSZ
        ;
    QUIT;

    /*Voeg prestatiejaar toe*/    
    DATA INCLab_&EEJJ.;
    
        SET INCLab_&EEJJ.;
    
        annee_prest = %eval(&EEJJ.);

    RUN; 
    
    PROC MEANS DATA=INCLab_&EEJJ.;
        VAR REMDAYS ASSIMDAYS REMUN;
    RUN;

    /*Test of een individu nog meer dan 1 keer voorkomt in het bestand*/
    PROC SQL;
        CREATE TABLE COUNT_Indiv AS
        SELECT COUNT(*) AS NUM_Indiv
        FROM INCLab_&EEJJ.
        GROUP BY GECODEERD_INSZ
        ;
    QUIT;

    PROC FREQ DATA=COUNT_Indiv;
        TITLE "Frequentie van het aantal keer dat een individu voorkomt in het bestand van &EEJJ.";
        TABLES NUM_Indiv;
    RUN;

%MEND ForEach;
/*Voer macro uit voor alle observatiejaren*/
%ForEach(2002);
%ForEach(2003);
%ForEach(2004);
%ForEach(2005);
%ForEach(2006);
%ForEach(2007);
%ForEach(2008);

/*Voeg verschillende jaarbestanden samen tot n geheel dat complement vormt met andere cimire-gegevens*/
%MACRO COMBIN;
DATA LIBW.CAREERINFO_SINCE2002;
    
    SET
    %DO I = 2002 %to 2008;
        INCLab_&I.
    %END;
    ;
    
    Label ASSIMDAYS = "Number of assimilated days in a given year";
    Label REMDAYS   = "Remunerated days per year";
    Label REMUN     = "Remunerations in Euro per year (expressed in prices of the year of registration)";
    Label REMHOURS  = "Remunerated hours per year";

RUN;
%MEND COMBIN;
%COMBIN;

PROC MEANS DATA=LIBW.CAREERINFO_SINCE2002;
    VAR REMDAYS ASSIMDAYS REMUN REMHOURS;
    CLASS annee_prest;
RUN;

/*Test of een individu nog meer dan 1 keer voorkomt in het bestand*/
PROC SQL;
    CREATE TABLE COUNT_Indiv AS
    SELECT COUNT(*) AS NUM_Indiv
    FROM LIBW.CAREERINFO_SINCE2002
    GROUP BY GECODEERD_INSZ
    ;
QUIT;

PROC FREQ DATA=COUNT_Indiv;
    TITLE "Frequentie van het aantal keer dat een individu voorkomt in het finale bestand na samenvoeging";
    TABLES NUM_Indiv;
RUN;
/*einde programma*/
PROC PRINTTO LOG=LOG PRINT=PRINT;
RUN;

