/*use options to print info on running of macro proces*/
OPTIONS MPRINT MLOGIC SYMBOLGEN; 
/*Define log file and be sure it is made empty before a new run*/
FILENAME mylog 'C:\My\teksten\MIMS2009\DataFS\ProgManip\CreateDaysForT23andT24_Ext.log';
FILENAME myout 'C:\My\teksten\MIMS2009\DataFS\ProgManip\CreateDaysForT23andT24.txt';
DATA _NULL_; 
    FILE mylog;
RUN;
DATA _NULL_; 
    FILE myout;
RUN;
PROC PRINTTO LOG=mylog PRINT=myout;
RUN;

DM 'Log; CLEAR; Output; Clear; ';

/*Zet macro opties*/
OPTIONS MPRINT MLOGIC SYMBOLGEN;
/*Define library with latest version of CIMIRe data*/
LIBNAME CIMIRE 'C:\My\teksten\MIMS2009\DataFS\ORIG\';
LIBNAME RESULT 'C:\My\teksten\MIMS2009\DataFS\MANIP\';
/*Data in file 23 are registrations on individual level: number of career years should be derived by unfolding each line
we use the macro Unfold23 for this*/
%Macro Unfold23;
/*Create temporary file with starting and ending dates of file 23*/
DATA FILE23;
    SET CIMIRE.mim2008_cimire_t23_2001_code(KEEP = gecodeerd_insz code_carriere date_deb_2008 date_fin_2008 RENAME=(date_deb_2008=begindatum date_fin_2008=einddatum));
    /*read in numeric values of start and stop year*/
    /*only fill in value if date is known*/
    yearSTART = 0;
    monthSTART = 0;
    IF SUBSTR(TRIM(begindatum),1,1) NE '.' AND SUBSTR(TRIM(begindatum),1,1) NE '-' AND SUBSTR(TRIM(begindatum),1,1) NE ' ' THEN DO;
        yearSTART  = INPUT(SUBSTR(TRIM(begindatum),4,4),8.);
        monthSTART = INPUT(SUBSTR(TRIM(begindatum),1,2),8.);
    END;
    /*only fill in value if date is known*/
    yearSTOP = 0;
    monthSTOP = 0;
    IF SUBSTR(TRIM(einddatum),1,1) NE '.' AND SUBSTR(TRIM(einddatum),1,1) NE '-' AND SUBSTR(TRIM(einddatum),1,1) NE ' ' THEN DO;
        yearSTOP = INPUT(SUBSTR(TRIM(einddatum),4,4),8.);
        monthSTOP = INPUT(SUBSTR(TRIM(einddatum),1,2),8.);
    END;
    /*treat missing or impossible values*/
    /*For year*/
    IF yearSTART NE 0 AND yearSTOP EQ 0 THEN yearSTOP = yearSTART;
    IF yearSTART EQ 0 AND yearSTOP NE 0 THEN yearSTART = yearSTOP;
    IF yearSTART EQ 0 AND yearSTOP EQ 0 THEN DO;
        yearSTART = 2001;
        yearSTOP = 2001;
    END;
    IF yearSTART GT yearSTOP THEN yearSTART = yearSTOP;
    /*For month*/
    IF monthSTART GT 12 THEN monthSTART = 12;
    IF monthSTOP  GT 12 THEN monthSTOP  = 12;
    IF monthSTART NE 0 AND monthSTOP EQ 0 THEN monthSTOP = monthSTART;
    IF monthSTART EQ 0 AND monthSTOP NE 0 THEN monthSTART = monthSTOP;
    IF monthSTART EQ 0 AND monthSTOP EQ 0 THEN DO;
        monthSTART = 1;
        monthSTOP = 1;
    END;
    IF yearSTART EQ yearSTOP AND monthSTART GT monthSTOP THEN monthSTART = monthSTOP;
RUN;
PROC FREQ DATA=FILE23;
    TABLES yearSTART yearSTOP monthSTART monthSTOP;
RUN;  
PROC PRINT DATA=FILE23(obs=100);
RUN;
/*Determine the number of observations in the file with start and end date and store this value in a macro variable*/
PROC SQL NOPRINT;
    SELECT NOBS
        INTO    :numobs
        FROM    DICTIONARY.TABLES
        WHERE   UPCASE(LIBNAME) = "WORK"
                AND
                UPCASE(MEMNAME) = "FILE23"
                ;
QUIT;
/*Read values of start date and end date into macrovariables (i.e. for each individual two variables are created)*/
PROC SQL NOPRINT;
    SELECT yearSTART, yearSTOP, monthSTART, monthSTOP, begindatum, code_carriere, gecodeerd_insz  
        INTO   :InSTART1-:InSTART%eval(&numobs),
               :InSTOP1-:InSTOP%eval(&numobs),
               :InMONSTA1-:InMONSTA%eval(&numobs),
               :InMONSTO1-:InMONSTO%eval(&numobs),
               :InBD1-:InBD%eval(&numobs),
               :InCC1-:InCC%eval(&numobs),
               :IndivID1-:IndivID%eval(&numobs)
        FROM    FILE23
                ;
QUIT;
/*loop over all individuals and create a data set with the necessary number of lines*/
/*each line should contain the individual identification number and a unique career year value that is observed in file 23*/
%DO i=1 %TO %eval(&numobs);
    DATA Test&i;
        LENGTH gecodeerd_insz   $17.;
        LENGTH code_carriere    $3.;
        LENGTH begindatum       $25.;
        /*loop over all possible years for an individual and output each time the created results*/
        %DO j=1 %TO %eval(&&InSTOP&i) - %eval(&&InSTART&i) + 1;
            %IF (%eval(&&InSTOP&i) - %eval(&&InSTART&i) + 1) EQ 1 %THEN %DO;
                annee_prest     = %eval(&&InSTART&i) + %eval(&j) - 1;
                jour_assimil    = (%eval(&&InMONSTO&i) - %eval(&&InMONSTA&i) + 1)*26;
                gecodeerd_insz  = %unquote(%str(%"&&IndivID&i%"));
                code_carriere   = %unquote(%str(%"&&InCC&i%"));
                begindatum      = %unquote(%str(%"&&InBD&i%"));
            %END;
            %ELSE %DO;
                %IF %eval(&j) EQ 1 %THEN %DO;
                    annee_prest     = %eval(&&InSTART&i) + %eval(&j) - 1;
                    jour_assimil    = (12 - %eval(&&InMONSTA&i) + 1)*26;
                    gecodeerd_insz  = %unquote(%str(%"&&IndivID&i%"));
                    code_carriere   = %unquote(%str(%"&&InCC&i%"));
                    begindatum      = %unquote(%str(%"&&InBD&i%"));
                %END;    
                %ELSE %IF %eval(&j) GT 1 AND %eval(&j) LT (%eval(&&InSTOP&i) - %eval(&&InSTART&i) + 1) %THEN %DO;
                    annee_prest     = %eval(&&InSTART&i) + %eval(&j) - 1;
                    jour_assimil    = 12*26;
                    gecodeerd_insz  = %unquote(%str(%"&&IndivID&i%"));
                    code_carriere   = %unquote(%str(%"&&InCC&i%"));
                    begindatum      = %unquote(%str(%"&&InBD&i%"));
                %END;
                %ELSE %DO;
                    annee_prest     = %eval(&&InSTART&i) + %eval(&j) - 1;
                    jour_assimil    = %eval(&&InMONSTO&i)*26;
                    gecodeerd_insz  = %unquote(%str(%"&&IndivID&i%"));
                    code_carriere   = %unquote(%str(%"&&InCC&i%"));
                    begindatum      = %unquote(%str(%"&&InBD&i%"));
                %END;
            %END;
            OUTPUT;
        %END;
    RUN;
    %IF %eval(&i) EQ 1 %THEN %DO;
        PROC PRINT DATA=Test&i;
        RUN;
    %END;
%END;
/*Combine all the individual files into a single file*/
DATA Final_FILE23;
    SET
    %DO i=1 %TO %eval(&numobs);
         Test&i
    %END;
    ;
RUN;
/*Zorg er voor dat indien er meerdere lijnen zijn met dezelfde begindatum dat je dan enkel n lijn over houdt*/
PROC SORT DATA=Final_FILE23;
    BY gecodeerd_insz annee_prest code_carriere begindatum jour_assimil;
RUN;
DATA Final_FILE23;
    SET Final_FILE23;
    BY gecodeerd_insz annee_prest code_carriere begindatum;
    IF last.begindatum THEN OUTPUT;
RUN;
DATA RESULT.Final_FILE23;
    SET Final_FILE23;
    KEEP gecodeerd_insz annee_prest code_carriere jour_assimil;
RUN;
%MEND Unfold23;
%Unfold23;
PROC FREQ DATA=RESULT.Final_FILE23;
    TABLES code_carriere;
RUN;    
PROC MEANS DATA=RESULT.Final_FILE23;
    VAR jour_assimil;
RUN;    
PROC PRINT DATA=RESULT.Final_FILE23(obs=100);
RUN;    
/****T24****/
%Macro Unfold24;
/*Create temporary file with starting and ending dates of file 24*/
DATA FILE24;
    SET CIMIRE.mim2008_cimire_t24_2001_code(KEEP = gecodeerd_insz code_carriere date_1_2008 date_2_2008 date_3_2008 RENAME=(date_1_2008=date_1 date_2_2008=date_2 date_3_2008=date_3));
    /*read in numeric values of start and stop year*/
    /*only fill in value if date is known*/
    yearSTART = 0;
    monthSTART = 0;
    IF SUBSTR(TRIM(date_1),1,1) NE '.' AND SUBSTR(TRIM(date_1),1,1) NE '-' AND SUBSTR(TRIM(date_1),1,1) NE ' ' THEN DO;
        yearSTART = INPUT(SUBSTR(TRIM(date_1),4,4),8.);
        monthSTART = INPUT(SUBSTR(TRIM(date_1),1,2),8.);
    END;
    /*read numeric values of date 2 and date 3 and select the appropriate value of yearSTOP*/
    valuedate_2 = 0;
    valuemonth_2 = 0;
    IF SUBSTR(TRIM(date_2),1,1) NE '.' AND SUBSTR(TRIM(date_2),1,1) NE '-' AND SUBSTR(TRIM(date_2),1,1) NE ' ' THEN DO;
        valuedate_2 = INPUT(SUBSTR(TRIM(date_2),4,4),8.);
        valuemonth_2 = INPUT(SUBSTR(TRIM(date_2),1,2),8.);
    END;
    valuedate_3 = 0;
    valuemonth_3 = 0;
    IF SUBSTR(TRIM(date_3),1,1) NE '.' AND SUBSTR(TRIM(date_3),1,1) NE '/' AND SUBSTR(TRIM(date_3),1,1) NE ' ' THEN DO;
        valuedate_3 = INPUT(SUBSTR(TRIM(date_3),1,4),8.);
        valuemonth_3 = INPUT(SUBSTR(TRIM(date_3),5,2),8.);
    END;
    yearSTOP = 0;
    IF valuedate_2 NE 0 AND valuedate_3 EQ 0 THEN yearSTOP = valuedate_2;
    IF valuedate_2 EQ 0 AND valuedate_3 NE 0 THEN yearSTOP = valuedate_3;
    IF valuedate_2 NE 0 AND valuedate_3 NE 0 AND valuedate_2 GE valuedate_3 THEN yearSTOP = valuedate_2;
    IF valuedate_2 NE 0 AND valuedate_3 NE 0 AND valuedate_2 LT valuedate_3 THEN yearSTOP = valuedate_3;
    monthSTOP = 0;
    IF valuemonth_2 NE 0 AND valuemonth_3 EQ 0 THEN monthSTOP = valuemonth_2;
    IF valuemonth_2 EQ 0 AND valuemonth_3 NE 0 THEN monthSTOP = valuemonth_3;
    IF valuemonth_2 NE 0 AND valuemonth_3 NE 0 AND valuemonth_2 GE valuemonth_3 THEN monthSTOP = valuemonth_2;
    IF valuemonth_2 NE 0 AND valuemonth_3 NE 0 AND valuemonth_2 LT valuemonth_3 THEN monthSTOP = valuemonth_3;
    /*treat missing or impossible values*/
    /*For year*/
    IF yearSTART NE 0 AND yearSTOP EQ 0 THEN yearSTOP = yearSTART;
    IF yearSTART EQ 0 AND yearSTOP NE 0 THEN yearSTART = yearSTOP;
    IF yearSTART EQ 0 AND yearSTOP EQ 0 THEN DO;
        yearSTART = 2001;
        yearSTOP = 2001;
    END;
    IF yearSTART GT yearSTOP THEN yearSTART = yearSTOP;
    /*For month*/
    IF monthSTART NE 0 AND monthSTOP EQ 0 THEN monthSTOP = monthSTART;
    IF monthSTART EQ 0 AND monthSTOP NE 0 THEN monthSTART = monthSTOP;
    IF monthSTART EQ 0 AND monthSTOP EQ 0 THEN DO;
        monthSTART = 1;
        monthSTOP = 1;
    END;
    IF yearSTART EQ yearSTOP AND monthSTART GT monthSTOP THEN monthSTART = monthSTOP;
RUN;
PROC FREQ DATA=FILE24;
    TABLES yearSTART yearSTOP monthSTART monthSTOP;
RUN;    
PROC PRINT DATA=FILE24(obs=100);
RUN;
/*Determine the number of observations in the file with start and end date and store this value in a macro variable*/
PROC SQL NOPRINT;
    SELECT NOBS
        INTO    :numobs
        FROM    DICTIONARY.TABLES
        WHERE   UPCASE(LIBNAME) = "WORK"
                AND
                UPCASE(MEMNAME) = "FILE24"
                ;
QUIT;
/*Read values of start date and end date into macrovariables (i.e. for each individual two variables are created)*/
PROC SQL NOPRINT;
    SELECT yearSTART, yearSTOP, monthSTART, monthSTOP, date_1, code_carriere, gecodeerd_insz  
        INTO   :InSTART1-:InSTART%eval(&numobs),
               :InSTOP1-:InSTOP%eval(&numobs),
               :InMONSTA1-:InMONSTA%eval(&numobs),
               :InMONSTO1-:InMONSTO%eval(&numobs),
               :InBD1-:InBD%eval(&numobs),
               :InCC1-:InCC%eval(&numobs),
               :IndivID1-:IndivID%eval(&numobs)
        FROM    FILE24
                ;
QUIT;
/*loop over all individuals and create a data set with the necessary number of lines*/
/*each line should contain the individual identification number and a unique career year value that is observed in file 24*/
%DO i=1 %TO %eval(&numobs);
    DATA Test&i;
        LENGTH gecodeerd_insz $17.;
        LENGTH code_carriere  $3.;
        LENGTH begindatum     $7.;
        /*loop over all possible years for an individual and output each time the created results*/
        %DO j=1 %TO %eval(&&InSTOP&i) - %eval(&&InSTART&i) + 1;
            %IF (%eval(&&InSTOP&i) - %eval(&&InSTART&i) + 1) EQ 1 %THEN %DO;
                annee_prest     = %eval(&&InSTART&i) + %eval(&j) - 1;
                jour_assimil    = (%eval(&&InMONSTO&i) - %eval(&&InMONSTA&i) + 1)*26;
                gecodeerd_insz  = %unquote(%str(%"&&IndivID&i%"));
                code_carriere   = %unquote(%str(%"&&InCC&i%"));
                begindatum      = %unquote(%str(%"&&InBD&i%"));
            %END;
            %ELSE %DO;
                %IF %eval(&j) EQ 1 %THEN %DO;
                    annee_prest     = %eval(&&InSTART&i) + %eval(&j) - 1;
                    jour_assimil    = (12 - %eval(&&InMONSTA&i) + 1)*26;
                    gecodeerd_insz  = %unquote(%str(%"&&IndivID&i%"));
                    code_carriere   = %unquote(%str(%"&&InCC&i%"));
                    begindatum      = %unquote(%str(%"&&InBD&i%"));
                %END;    
                %ELSE %IF %eval(&j) GT 1 AND %eval(&j) LT (%eval(&&InSTOP&i) - %eval(&&InSTART&i) + 1) %THEN %DO;
                    annee_prest     = %eval(&&InSTART&i) + %eval(&j) - 1;
                    jour_assimil    = 12*26;
                    gecodeerd_insz  = %unquote(%str(%"&&IndivID&i%"));
                    code_carriere   = %unquote(%str(%"&&InCC&i%"));
                    begindatum      = %unquote(%str(%"&&InBD&i%"));
                %END;
                %ELSE %DO;
                    annee_prest     = %eval(&&InSTART&i) + %eval(&j) - 1;
                    jour_assimil    = %eval(&&InMONSTO&i)*26;
                    gecodeerd_insz  = %unquote(%str(%"&&IndivID&i%"));
                    code_carriere   = %unquote(%str(%"&&InCC&i%"));
                    begindatum      = %unquote(%str(%"&&InBD&i%"));
                %END;
            %END;
            OUTPUT;
        %END;
    RUN;
    %IF %eval(&i) EQ 1 %THEN %DO;
        PROC PRINT DATA=Test&i;
        RUN;
    %END;
%END;
/*Combine all the individual files into a single file*/
DATA Final_FILE24;
    SET
    %DO i=1 %TO %eval(&numobs);
         Test&i
    %END;
    ;
RUN;
/*Zorg er voor dat indien er meerdere lijnen zijn met dezelfde begindatum dat je dan enkel n lijn over houdt*/
PROC SORT DATA=Final_FILE24;
    BY gecodeerd_insz annee_prest code_carriere begindatum jour_assimil;
RUN;
DATA Final_FILE24;
    SET Final_FILE24;
    BY gecodeerd_insz annee_prest code_carriere begindatum;
    IF last.begindatum THEN OUTPUT;
RUN;
DATA RESULT.Final_FILE24;
    SET Final_FILE24;
    KEEP gecodeerd_insz annee_prest code_carriere jour_assimil;
RUN;
%MEND Unfold24;
%Unfold24;
PROC FREQ DATA=RESULT.Final_FILE24;
    TABLES code_carriere;
RUN;    
PROC MEANS DATA=RESULT.Final_FILE24;
    VAR jour_assimil;
RUN; 
PROC PRINT DATA=RESULT.Final_FILE24(obs=100);
RUN; 
/*einde programma*/
PROC PRINTTO LOG=LOG PRINT=PRINT;
RUN;
