/*
Programma maakt input-variabelen mimosis aan 
    op basis van gegevens PIT en ADSEI
*/    
FILENAME mylog 'C:\My\teksten\MIMS2009\DataFS\ProgManip\CreatePIT_COSTCAL.log';
FILENAME myout 'C:\My\teksten\MIMS2009\DataFS\ProgManip\CreatePIT_COSTCAL.txt';
DATA _NULL_; 
    FILE mylog;
RUN;
DATA _NULL_; 
    FILE myout;
RUN;
PROC PRINTTO LOG=mylog PRINT=myout;
RUN;

/*Zet bibliotheek-namen*/
LIBNAME LIB     'C:\My\teksten\MIMS2009\DataFS\ORIG\';
LIBNAME LIBW    'C:\My\teksten\MIMS2009\DataFS\MANIP\';

DM 'Log; CLEAR; Output; Clear; ';

/*Zet macro opties*/
OPTIONS MPRINT MLOGIC SYMBOLGEN;

/*Lees quantielnummer fiscale eenheid*/
FILENAME QUANTNUM 'C:\My\teksten\MIMS2009\DataFS\ProgManip\PIT_QUANTNUM.txt';
DATA QUANTNUM;
    INFILE QUANTNUM lrecl=34 missover;
    input 
    GECODEERD_INSZ                $    1-14
    PIT_TUNUMB_ANN                    15-24  
    QNR_TNTI                          25-34  
    ;
    LABEL PIT_TUNUMB_ANN = "Unique identification number of the tax unit";
    LABEL QNR_TNTI       = "Vector with quantile numbers based on total net taxable income";
RUN;
PROC PRINT DATA=QUANTNUM(obs=10);
    TITLE "Observaties uit Quantnum";
RUN;
/*Lees geobserveerde en geschatte decielwaarden in*/
DATA DECINFO;
    INPUT @1 DECNUM 20.0 @21 ESTADS 20.0 @41 ESTPIT 20.0;
    DATALINES;
1                              881090524          3143728646
2                             5185634199          6630062816
3                             7491804651          8457761514
4                             9190184310         10536506821
5                            11257736991         12783893353
6                            13558257618         14935938196
7                            16276426069         17494280987
8                            20367817827         21228498745
9                            27493259624         28152599014
91                            3361125300          3397745911
92                            3520440662          3549813312
93                            3700288961          3709542723
94                            3904114254          3895218208
95                            4145462385          4114804953
96                            4447023528          4395464799
97                            4842265753          4755268211
98                            5417005578          5266558898
99                            6468450597          6121166023
100                          12650775385         10425865870
   ;
RUN;   
DATA DECINFO;

    SET DECINFO;

    COSTRATE = 0;
    IF ESTPIT NE 0 THEN COSTRATE = ESTADS/ESTPIT;
    ESTADS_SIM = COSTRATE*ESTPIT;
    
RUN;
PROC PRINT DATA=DECINFO;
    TITLE "Gegevens per deciel van ADSEI en op basis van PIT";
RUN;
PROC MEANS DATA=DECINFO sum;
    TITLE "Som belastbaar netto inkomen ADSEI en PIT";
    VAR ESTADS ESTPIT;
RUN;    
/*Maak bestand met geobserveerde quantielnummers*/
DATA QUANTNUM_REDUC;

    SET QUANTNUM(WHERE=(QNR_TNTI<>0));
    
    DECNUM = QNR_TNTI;
    IF QNR_TNTI LE 10                       THEN DECNUM = 1;
    IF QNR_TNTI GT 10 AND QNR_TNTI LE 20    THEN DECNUM = 2;
    IF QNR_TNTI GT 20 AND QNR_TNTI LE 30    THEN DECNUM = 3;
    IF QNR_TNTI GT 30 AND QNR_TNTI LE 40    THEN DECNUM = 4;
    IF QNR_TNTI GT 40 AND QNR_TNTI LE 50    THEN DECNUM = 5;
    IF QNR_TNTI GT 50 AND QNR_TNTI LE 60    THEN DECNUM = 6;
    IF QNR_TNTI GT 60 AND QNR_TNTI LE 70    THEN DECNUM = 7;
    IF QNR_TNTI GT 70 AND QNR_TNTI LE 80    THEN DECNUM = 8;
    IF QNR_TNTI GT 80 AND QNR_TNTI LE 90    THEN DECNUM = 9;

RUN;
PROC FREQ DATA=QUANTNUM_REDUC;
    TITLE "Decielnummers op basis van gereduceerde file";
    TABLES DECNUM;
RUN;    
/*Test of een fiscale eenheid nog meer dan 1 keer voorkomt in het bestand*/
PROC SQL;
    CREATE TABLE COUNT_Indiv AS
    SELECT COUNT(*) AS NUM_Indiv
    FROM QUANTNUM_REDUC
    GROUP BY PIT_TUNUMB_ANN
    ;
QUIT;
PROC FREQ DATA=COUNT_Indiv;
    TITLE "Frequentie van het aantal keer dat een fiscale eenheid voorkomt in het gereduceerde bestand";
    TABLES NUM_Indiv;
RUN;
/*Voeg decielnummer en decielinfo samen*/
PROC SORT DATA=QUANTNUM_REDUC;
    BY DECNUM;
RUN;
PROC SORT DATA=DECINFO;
    BY DECNUM;
RUN;
DATA QUANTNUM_REDUC;

    MERGE QUANTNUM_REDUC DECINFO;
    BY DECNUM;
    
    KEEP PIT_TUNUMB_ANN COSTRATE;
    
RUN;
/*Voeg gegevens fiscale eenheid toe op individueel niveau*/
PROC SORT DATA=QUANTNUM_REDUC;
    BY PIT_TUNUMB_ANN;
RUN;
PROC SORT DATA=QUANTNUM;
    BY PIT_TUNUMB_ANN;
RUN;
DATA LIBW.MIM2008_PITCOST;

    MERGE QUANTNUM(in=InA) QUANTNUM_REDUC;
    BY PIT_TUNUMB_ANN;
    
    IF InA EQ 1;
    
    LABEL COSTRATE = "Fractie waarmee geobserveerd belastbaar netto inkomen vermenigvuldigd wordt om niet geobserveerde kosten en inkomens te benaderen";
    
    KEEP GECODEERD_INSZ COSTRATE;
    
RUN;
PROC PRINT DATA=LIBW.MIM2008_PITCOST(obs=10);
    TITLE "Observaties uit Quantnum_Fin";
RUN;
/*Einde programma*/
PROC PRINTTO LOG=LOG PRINT=PRINT;
RUN;
