/*
Programma voegt 
    steekproefgegevens en een aantal rijksregister-gegevens samen
    maakt individuele en huishoudgewichten aan
*/    
FILENAME mylog 'C:\My\teksten\MIMS2009\DataFS\ProgManip\CreatePopCharAndWeights_Ext.log';
FILENAME myout 'C:\My\teksten\MIMS2009\DataFS\ProgManip\CreatePopCharAndWeights.txt';
DATA _NULL_; 
    FILE mylog;
RUN;
DATA _NULL_; 
    FILE myout;
RUN;
PROC PRINTTO LOG=mylog PRINT=myout;
RUN;

DM 'Log; CLEAR; Output; Clear; ';

/*Zet bibliotheek-namen*/
LIBNAME LIB     'C:\My\teksten\MIMS2009\DataFS\ORIG\';
LIBNAME LIBW    'C:\My\teksten\MIMS2009\DataFS\MANIP\';

/*test huishoudomvang op basis van niet gemanipuleerde referentiepersoon*/
PROC FREQ DATA=LIB.mim2008_sample_code NOPRINT;
    TABLES gecodeerd_insz_ref / OUT=OutFreq;
RUN;
PROC FREQ DATA=OutFreq;
    TITLE "Aantal verschillende referentiepersonen in de steekproef";
    TABLES COUNT;
RUN;    
/*Voeg gegevens steekproef en pop char samen*/
/*Manipulaties voor NAREGNIS_REFPERS moeten opnieuw gebeuren omwille van conversie op het einde van steekproefprogramma*/
DATA TEST;
    SET LIB.mim2008_sample_code(RENAME=(gecodeerd_insz_ref=gecodeerd_insz_ref_sample));
RUN;
PROC SORT DATA=TEST;
    BY gecodeerd_insz;
RUN;   
DATA POPCHAR;
    SET LIB.mim2008_popchars_rr_code(DROP = NAREGNIS_RND_SLCT NAREGNIS_HH_ID);
RUN;
PROC SORT DATA=POPCHAR;
    BY gecodeerd_insz;
RUN;   
DATA OLD;
    SET LIB.mim2008_ms_geg_rr_ed_01_new_code(KEEP = gecodeerd_insz gecodeerd_insz_ref RENAME=(gecodeerd_insz_ref=gecodeerd_insz_ref_old));
RUN;
PROC SORT DATA=OLD;
    BY GECODEERD_INSZ;
RUN; 
DATA POPCHAR;

    MERGE TEST(in=InA) POPCHAR OLD;
    BY gecodeerd_insz;
    IF InA EQ 1;
    
    /*Maak de variabele NAREGNIS_REFPERS aan*/
    /*We houden gecodeerd_insz_ref uit sample over: is de niet gemanipuleerde versie
    die in popchar is wel gemanipuleerd, maar die houden we hier dus niet over*/
    NAREGNIS_REFPERS = gecodeerd_insz_ref_sample;
    IF TRIM(gecodeerd_insz_ref_sample) EQ "" AND TRIM(gecodeerd_insz_ref) NE "" THEN NAREGNIS_REFPERS = gecodeerd_insz_ref;
    IF TRIM(NAREGNIS_REFPERS) EQ "" AND TRIM(gecodeerd_insz_ref_old) NE ""      THEN NAREGNIS_REFPERS = gecodeerd_insz_ref_old;
        
    /*indien na deze manipulaties het gezinshoofd ongekend is, is het individu zelf het gezinshoofd en wordt verder verondersteld
    dat het om een alleenstaand indivdu gaat*/
    IF gecodeerd_insz_ref EQ "" THEN DO;
        NAREGNIS_REFPERS = gecodeerd_insz;
        NAREGNIS_HEADOFHH = 1;
    END;        
    IF NAREGNIS_RELATION  EQ 20 THEN DO;
        NAREGNIS_REFPERS = gecodeerd_insz;
        NAREGNIS_HEADOFHH = 1;
    END;        
    
    /*Corrigeer n specifiek geval: persoon met referentiepersoon waarvan referentiepersoon zelf een andere referentiepersoon heeft*/
    IF gecodeerd_insz EQ "persoon 198144" THEN NAREGNIS_REFPERS = "persoon 189700";

    /*Maak provincie*/
    IF NAREGNIS_COMMUNIT GE 11000 AND NAREGNIS_COMMUNIT LE 13053 THEN PROV = 1;
    IF NAREGNIS_COMMUNIT GE 21001 AND NAREGNIS_COMMUNIT LE 21019 THEN PROV = 2;
    IF NAREGNIS_COMMUNIT GE 23002 AND NAREGNIS_COMMUNIT LE 24137 THEN PROV = 3;
    IF NAREGNIS_COMMUNIT GE 25005 AND NAREGNIS_COMMUNIT LE 25124 THEN PROV = 4;
    IF NAREGNIS_COMMUNIT GE 31003 AND NAREGNIS_COMMUNIT LE 38025 THEN PROV = 5;
    IF NAREGNIS_COMMUNIT GE 41002 AND NAREGNIS_COMMUNIT LE 46025 THEN PROV = 6;
    IF NAREGNIS_COMMUNIT GE 51004 AND NAREGNIS_COMMUNIT LE 57095 THEN PROV = 7;
    IF NAREGNIS_COMMUNIT GE 61003 AND NAREGNIS_COMMUNIT LE 64076 THEN PROV = 8;
    IF NAREGNIS_COMMUNIT GE 71002 AND NAREGNIS_COMMUNIT LE 73109 THEN PROV = 9;
    IF NAREGNIS_COMMUNIT GE 81001 AND NAREGNIS_COMMUNIT LE 85047 THEN PROV = 10;
    IF NAREGNIS_COMMUNIT GE 91005 AND NAREGNIS_COMMUNIT LE 93090 THEN PROV = 11;
    /*Maak gewest*/
    REGION = 0;
    IF PROV IN (1, 3, 5, 6, 9)      THEN REGION = 2;
    IF PROV IN (2)                  THEN REGION = 1;
    IF PROV IN (4, 7, 8, 10, 11)    THEN REGION = 3;
    
    NAREGNIS_RND_SLCT = RND_SLCT_COMB;
    IF NAREGNIS_RND_SLCT EQ . THEN NAREGNIS_RND_SLCT = 0; 
    LABEL NAREGNIS_RND_SLCT   = "Aanduiding of het individu geselecteerd werd bij het trekken van de steekproef (= ja of nee)";
    LABEL NAREGNIS_REFPERS    = "Gecodeerd insz van de referentiepersoon";

    /*Leeftijd*/
    indexstreepje = INDEX(NAREGNIS_DATBIRTH,'-');
    yearbirth     = INPUT(SUBSTR(NAREGNIS_DATBIRTH,indexstreepje+1,4),8.);
    monthbirth    = INPUT(SUBSTR(NAREGNIS_DATBIRTH,1,indexstreepje-1),8.);
    Leeftijd      = FLOOR(((2008 - yearbirth)*12 + monthbirth)/12);
    AGE = 9999999;
    IF NAREGNIS_DATBIRTH NE "9999999" AND TRIM(NAREGNIS_DATBIRTH) NE "-" THEN AGE = Leeftijd ;

    DROP gecodeerd_insz_ref indexstreepje yearbirth monthbirth Leeftijd gecodeerd_insz_ref_sample gecodeerd_insz_ref_old RND_SLCT_COMB RND_SLCT_NEW RND_SLCT_OLD ;

RUN;
/*Tel het aantal gevallen waarvoor het nummer van de referentiepersoon nog onbekend is*/
PROC SQL;
    CREATE TABLE COUNTHH_Ref AS
    SELECT COUNT(*) AS NumHH_Ref
    FROM POPCHAR
    WHERE TRIM(NAREGNIS_REFPERS) = "";
QUIT;    
PROC PRINT DATA=COUNTHH_Ref;
    TITLE "Aantal gevallen met een onbekende referentiepersoon";
    VAR NumHH_Ref;
RUN;    
/*Maak opnieuw uniek huishoudnummer aan*/
PROC SQL;
    CREATE TABLE HH_ID AS
    SELECT DISTINCT NAREGNIS_REFPERS
    FROM POPCHAR
    ORDER BY NAREGNIS_REFPERS;
QUIT;    
DATA HH_ID;
    SET HH_ID;
    BY NAREGNIS_REFPERS;
    NAREGNIS_HH_ID = _N_;

    LABEL NAREGNIS_HH_ID      = "Geanonimiseerd identificatienummer van het gezin waartoe het individu behoort";

RUN; 
/*Voeg huishoudnummer toe aan bestand met karakteristieken*/
PROC SORT DATA=POPCHAR;
    BY NAREGNIS_REFPERS;
RUN;    
PROC SORT DATA=HH_ID;
    BY NAREGNIS_REFPERS;
RUN;    
DATA POPCHAR;
    MERGE POPCHAR HH_ID;
    BY NAREGNIS_REFPERS;
RUN;    
/*test huishoudomvang op basis van aangemaakte hh_id*/
PROC FREQ DATA=POPCHAR NOPRINT;
    TABLES NAREGNIS_HH_ID / OUT=OutFreq;
RUN;
PROC FREQ DATA=OutFreq;
    TITLE "Huishoudomvang voor correctie";
    TABLES COUNT;
RUN;
/*Laat twee gezinnen vallen wegens onbetrouwbare samenstelling*/
PROC SORT DATA=OutFreq;
    BY NAREGNIS_HH_ID;
RUN;
PROC SORT DATA=POPCHAR;
    BY NAREGNIS_HH_ID;
RUN;
DATA POPCHAR;
    MERGE POPCHAR OutFreq;
    BY NAREGNIS_HH_ID;
RUN;
PROC PRINT DATA=POPCHAR(WHERE=(COUNT>25));
    TITLE "Print gezinnen met meer dan 25 gezinsleden";
RUN;
DATA POPCHAR;
    SET POPCHAR;
    
    IF COUNT GT 25 THEN DELETE;
    
    DROP COUNT PERCENT;
RUN;
/*test huishoudomvang op basis van aangemaakte hh_id*/
PROC FREQ DATA=POPCHAR NOPRINT;
    TABLES NAREGNIS_HH_ID / OUT=OutFreq;
RUN;
PROC FREQ DATA=OutFreq;
    TITLE "Huishoudomvang na correctie";
    TABLES COUNT;
RUN;
/*vanaf hier bijkomende correctie of aanmaak van een aantal variabelen*
/*Indien er maar n gezinslid is en NAREGNIS_RELATION staat niet op 1, pas dat dan aan*/
PROC FREQ DATA=POPCHAR;
    TITLE "NAREGNIS_RELATION voor correctie gezinshoofd";
    TABLES NAREGNIS_RELATION;
RUN;
PROC SQL;
    CREATE TABLE COUNT_HHMem AS
    SELECT NAREGNIS_HH_ID, COUNT(*) AS NUM_HHMem
    FROM POPCHAR
    GROUP BY NAREGNIS_HH_ID
    ORDER BY NAREGNIS_HH_ID
    ;
QUIT;
PROC SORT DATA=POPCHAR;
    BY NAREGNIS_HH_ID;
RUN;
DATA POPCHAR;
    MERGE POPCHAR COUNT_HHMem;
    BY NAREGNIS_HH_ID;
    
    IF NUM_HHMem EQ 1 AND NAREGNIS_RELATION NE 1 AND NAREGNIS_RELATION NE 20 THEN NAREGNIS_RELATION = 1;
    
    DROP NUM_HHMem;
RUN;
PROC FREQ DATA=POPCHAR;
    TITLE "NAREGNIS_RELATION na correctie gezinshoofd";
    TABLES NAREGNIS_RELATION;
RUN;
/*Tel hoeveel gezinnen er zijn*/
PROC SQL;
    CREATE TABLE COUNT_HH AS
    SELECT COUNT(DISTINCT NAREGNIS_HH_ID) AS NUM_HH
    FROM POPCHAR
    ;
QUIT;
PROC PRINT DATA=COUNT_HH;
    TITLE "Totaal aantal gezinnen";
RUN;
/*Tel hoeveel gezinshoofden er zijn per gezin*/
PROC SQL;
    CREATE TABLE COUNT_HHHead AS
    SELECT NAREGNIS_HH_ID, COUNT(*) AS NUM_HHHead
    FROM POPCHAR
    WHERE NAREGNIS_RELATION = 1 OR NAREGNIS_RELATION = 20
    GROUP BY NAREGNIS_HH_ID
    ORDER BY NAREGNIS_HH_ID
    ;
QUIT;
PROC FREQ DATA=COUNT_HHHead;
    TITLE "Totaal aantal gezinshoofden per gezin: voor correctie";
    TABLES NUM_HHHead;
RUN;  
/*Correctie voor gezinnen met teveel gezinshoofden*/
DATA POPCHAR_ADD;
    MERGE POPCHAR COUNT_HHHead;
    BY NAREGNIS_HH_ID;
RUN;
PROC SORT DATA=POPCHAR_ADD;
    BY GECODEERD_INSZ;
RUN;    
DATA OLD;
    SET LIB.mim2008_ms_geg_rr_ed_01_new_code;
RUN;
PROC SORT DATA=OLD;
    BY GECODEERD_INSZ;
RUN;    
DATA POPCHAR_ADD;
    MERGE POPCHAR_ADD(in=InA) OLD(KEEP = gecodeerd_insz gecodeerd_insz_ref);
    BY GECODEERD_INSZ;

    IF InA EQ 1;

RUN;
/*Indien de referentiepersoon voor 2002 gekend is maak dan de referentiepersoon van 2002 gelijk aan die van 2008
en zet voor alle gevallen de relatiecode van de niet referentiepersoon op 12 = geen familieband*/
PROC SQL;
    CREATE TABLE KnownRef AS
    SELECT NAREGNIS_HH_ID, gecodeerd_insz_ref AS gecodeerd_insz_ref_2002
    FROM POPCHAR_ADD
    WHERE NUM_HHHead > 1 AND TRIM(gecodeerd_insz_ref) NE ""
    ORDER BY NAREGNIS_HH_ID
    ;
QUIT;
PROC SORT DATA=POPCHAR_ADD;
    BY NAREGNIS_HH_ID;
RUN;    
DATA POPCHAR_ADD;
    MERGE POPCHAR_ADD KnownRef;
    BY NAREGNIS_HH_ID;
    
    /*Corrigeer referentiepersoon en relatiecode*/
    IF NUM_HHHead > 1  THEN DO;
        IF TRIM(gecodeerd_insz_ref_2002) NE ""  THEN NAREGNIS_REFPERS = gecodeerd_insz_ref_2002;
        IF NAREGNIS_RELATION EQ 1   AND gecodeerd_insz NE NAREGNIS_REFPERS   THEN DO;
            NAREGNIS_RELATION = 12;
            NAREGNIS_HEADOFHH = 0;
        END;            
    END;
    
    DROP NUM_HHHead gecodeerd_insz_ref gecodeerd_insz_ref_2002;
   
RUN;   
/*Tel hoeveel gezinshoofden er zijn per gezin: na correctie*/
PROC SQL;
    CREATE TABLE COUNT_HHHead AS
    SELECT NAREGNIS_HH_ID, COUNT(*) AS NUM_HHHead
    FROM POPCHAR_ADD
    WHERE NAREGNIS_RELATION = 1 OR NAREGNIS_RELATION = 20
    GROUP BY NAREGNIS_HH_ID
    ORDER BY NAREGNIS_HH_ID
    ;
QUIT;
PROC FREQ DATA=COUNT_HHHead;
    TITLE "Totaal aantal gezinshoofden per gezin: na correctie";
    TABLES NUM_HHHead;
RUN;  
/*Test of er voor ieder gezin maar 1 referentiepersoon voor komt*/
PROC SQL;
    CREATE TABLE COUNT_REF AS
    SELECT COUNT(DISTINCT NAREGNIS_REFPERS) AS NUM_REF
    FROM POPCHAR_ADD
    GROUP BY NAREGNIS_HH_ID
    ;
QUIT;
PROC FREQ DATA=COUNT_REF;
    TITLE "Totaal aantal referentiepersonen per gezin";
    TABLES NUM_REF;
RUN;
/*Test of er gezinnen zijn waar het gezinshoofd niet de referentiepersoon is*/
PROC SQL;
    CREATE TABLE COUNT_REFNot AS
    SELECT COUNT(*) AS NUM_REFNot
    FROM POPCHAR_ADD
    WHERE (NAREGNIS_RELATION = 1 OR NAREGNIS_RELATION = 20) AND GECODEERD_INSZ <> NAREGNIS_REFPERS
    ;
QUIT;
PROC PRINT DATA=COUNT_REFNot;
    TITLE "Aantal keer dat het gezinshoofd niet de referentiepersoon is";
    VAR NUM_REFNot;
RUN;    
/*Tel hoeveel partners er zijn per gezin*/
PROC SQL;
    CREATE TABLE COUNT_HHPart AS
    SELECT NAREGNIS_HH_ID, COUNT(*) AS NUM_HHPart
    FROM POPCHAR_ADD
    WHERE NAREGNIS_RELATION = 2
    GROUP BY NAREGNIS_HH_ID
    ORDER BY NAREGNIS_HH_ID
    ;
QUIT;
PROC FREQ DATA=COUNT_HHPart;
    TITLE "Totaal aantal partners per gezin";
    TABLES NUM_HHPart;
RUN;   
/*voeg aantal partners per gezin toe*/
DATA POPCHAR_ADD;
    MERGE POPCHAR_ADD COUNT_HHPart;
    BY NAREGNIS_HH_ID;
RUN;
PROC SORT DATA=POPCHAR_ADD;
    BY GECODEERD_INSZ;
RUN;
DATA POPCHAR_ADD;
    MERGE POPCHAR_ADD(in=InA) OLD(KEEP = gecodeerd_insz NAREGNIS_RELATION_2002 NAREGNIS_CIVIL_2002);
    BY GECODEERD_INSZ;

    IF InA EQ 1;

RUN;
PROC SORT DATA=POPCHAR_ADD;
    BY NAREGNIS_HH_ID;
RUN;
PROC PRINT DATA=POPCHAR_ADD(WHERE=(NUM_HHPart>1));
    TITLE "Gezinnen met meer dan 1 partner op 1 januari 2009";
    VAR NAREGNIS_RELATION NAREGNIS_HH_ID NAREGNIS_CIVIL_2002 NAREGNIS_DATBIRTH GECODEERD_INSZ; 
RUN;
/*Corrigeer gezinne met meer dan 1 partner manueel na inspectie van cases*/
DATA POPCHAR_ADD;

    SET POPCHAR_ADD;
    
    /*correctie gezin 2632*/
    IF gecodeerd_insz ="persoon 160307" THEN DO;
        NAREGNIS_RELATION = 3;
        NAREGNIS_CIVIL = 2;
    END;
    IF gecodeerd_insz ="persoon 294250" THEN DO;
        NAREGNIS_RELATION = 4;
        NAREGNIS_CIVIL = 2;
    END;
    /*correctie gezin 4609*/
    IF gecodeerd_insz ="persoon 202202" THEN DELETE;
    /*correctie gezin 13695*/
    IF gecodeerd_insz ="persoon 139208" THEN DELETE;
    /*correctie gezin 32330*/
    IF gecodeerd_insz ="persoon 226248" THEN NAREGNIS_RELATION = 3;
    /*correctie gezin 75821*/
    IF gecodeerd_insz ="persoon 239715" THEN DELETE;
    /*correctie gezin 78122*/
    IF gecodeerd_insz ="persoon 199435" THEN DO;
        NAREGNIS_RELATION = 4;
        NAREGNIS_CIVIL = 2;
    END;
    IF gecodeerd_insz ="persoon 238060" THEN NAREGNIS_CIVIL = 2;
    /*correctie gezin 78718*/
    IF gecodeerd_insz ="persoon 284706" THEN NAREGNIS_RELATION = 3;
    /*correctie gezin 91014*/
    IF gecodeerd_insz ="persoon 122045" THEN DELETE;

RUN;
/*Tel hoeveel partners er zijn per gezin: na correctie*/
PROC SQL;
    CREATE TABLE COUNT_HHPart AS
    SELECT NAREGNIS_HH_ID, COUNT(*) AS NUM_HHPart
    FROM POPCHAR_ADD
    WHERE NAREGNIS_RELATION = 2
    GROUP BY NAREGNIS_HH_ID
    ORDER BY NAREGNIS_HH_ID
    ;
QUIT;
PROC FREQ DATA=COUNT_HHPart;
    TITLE "Totaal aantal partners per gezin: na correctie";
    TABLES NUM_HHPart;
RUN;   
/*Constructie NAREGNIS_CIVIL*/
DATA SURPENS;
    SET LIB.mim2008_rvp_nationaallegaal_code(KEEP = GECODEERD_INSZ SPWE_2008 SPSE_2008 SPCIV_2008 SPFOR_2008 SPDOSZ_2008 SPRENT_SPILPRIV_2008 SPRENT_SPILPUB_2008 SPCAP_SPILPRIV_2008 SPCAP_SPILPUB_2008);

    SURPENS_INDIC = 0;
    IF SPWE_2008            = . THEN SPWE_2008 = 0;
    IF SPSE_2008            = . THEN SPSE_2008 = 0;
    IF SPCIV_2008           = . THEN SPCIV_2008 = 0;
    IF SPFOR_2008           = . THEN SPFOR_2008 = 0;
    IF SPDOSZ_2008          = . THEN SPDOSZ_2008 = 0;
    IF SPRENT_SPILPRIV_2008 = . THEN SPRENT_SPILPRIV_2008= 0;
    IF SPRENT_SPILPUB_2008  = . THEN SPRENT_SPILPUB_2008= 0; 
    IF SPCAP_SPILPRIV_2008  = . THEN SPCAP_SPILPRIV_2008= 0; 
    IF SPCAP_SPILPUB_2008   = . THEN SPCAP_SPILPUB_2008= 0;

    SURPENS_INDIC = SPWE_2008 + SPSE_2008 + SPCIV_2008 + SPFOR_2008 + SPDOSZ_2008 + SPRENT_SPILPRIV_2008 + SPRENT_SPILPUB_2008 + SPCAP_SPILPRIV_2008 + SPCAP_SPILPUB_2008;
    
    KEEP GECODEERD_INSZ SURPENS_INDIC;
RUN;
PROC SORT DATA=SURPENS;
    BY GECODEERD_INSZ;
RUN;    
PROC SORT DATA=POPCHAR_ADD;
    BY GECODEERD_INSZ;
RUN;
DATA POPCHAR;

    MERGE POPCHAR_ADD SURPENS;
    BY GECODEERD_INSZ;
    
    IF SURPENS_INDIC EQ . THEN SURPENS_INDIC = 0;

    /*We weten al dat er zeker een gezinshoofd is, indien er ook een partner is vullen we NAREGNIS_CIVIL in*/
    IF NUM_HHPart>0 AND (NAREGNIS_RELATION = 1 OR NAREGNIS_RELATION = 2)    THEN NAREGNIS_CIVIL = 2;
    /*Indien NAREGNIS_CIVIL = 0 en gekend in 2002 met waarde groter dan 2 vul dan die waarde in*/
    IF NAREGNIS_CIVIL = 0 AND NAREGNIS_CIVIL_2002 > 2                       THEN NAREGNIS_CIVIL = NAREGNIS_CIVIL_2002;
    /*Indien NAREGNIS_CIVIL = 0 (i.e. er is in 2009 geen partner meer) en 2 in 2002, splits dan in gescheiden of weduwnaar*/
    IF NAREGNIS_CIVIL = 0 AND SURPENS_INDIC > 0 AND AGE GT 18               THEN NAREGNIS_CIVIL = 3;

    /*constructie is op dit moment onvolledig: later volgt tweede stap*/

RUN;    
/*Tel hoeveel personen er zijn die gehuwd waren in 2002 en nu nog geen code civil hebben*/
PROC SQL;
    CREATE TABLE COUNT_HHDiv AS
    SELECT NAREGNIS_HH_ID, COUNT(*) AS NUM_HHDiv
    FROM POPCHAR
    WHERE NAREGNIS_CIVIL = 0 AND NAREGNIS_CIVIL_2002 = 2
    GROUP BY NAREGNIS_HH_ID
    ORDER BY NAREGNIS_HH_ID
    ;
QUIT;
PROC FREQ DATA=COUNT_HHDiv;
    TITLE "Totaal personen die gehuwd waren in 2002 en nu nog geen code civil hebben";
    TABLES NUM_HHDiv;
RUN;   
/*Pas resultaat gehuwd gescheiden verder aan*/
PROC SORT DATA=POPCHAR;
    BY NAREGNIS_HH_ID;
RUN;
DATA POPCHAR;

    MERGE POPCHAR COUNT_HHDiv;
    BY NAREGNIS_HH_ID;

    /*Gezinnen met n individu dat vroeger gehuwd was en nu niet meer en dat geen overlevingspensioen heeft: nieuwe status is gescheiden*/
    IF NAREGNIS_CIVIL = 0 AND SURPENS_INDIC = 0 AND NAREGNIS_CIVIL_2002 = 2 AND NUM_HHDiv = 1 AND AGE GT 18     THEN NAREGNIS_CIVIL = 4;
    /*Indien het gezinshoofd een code 2 had in 2002, NUM_HHDiv=3 en na de voorgaande operaties nog een onbekende status heeft: nieuwe status is gescheiden*/
    IF NAREGNIS_CIVIL = 0 AND NAREGNIS_RELATION = 1 AND NAREGNIS_CIVIL_2002 = 2 AND NUM_HHDiv = 3 AND AGE GT 18 THEN NAREGNIS_CIVIL = 4;
    /*Gezinnen met meer dan n individu dat vroeger gehuwd was en nu nog civil status = 0: nieuwe status = gehuwd*/
    IF NAREGNIS_CIVIL = 0 AND NAREGNIS_CIVIL_2002 = 2 AND NUM_HHDiv > 1 AND AGE GT 18                           THEN NAREGNIS_CIVIL = 2;
    /*resterende gevallen zijn singles*/
    IF NAREGNIS_CIVIL = 0                                                                                       THEN NAREGNIS_CIVIL = 1;
    
    DROP NUM_HHPart NAREGNIS_RELATION_2002 NAREGNIS_CIVIL_2002 SURPENS_INDIC NUM_HHDiv AGE;
    
RUN;
/*Frequentieverdeling burgerlijke staat*/
PROC FREQ DATA=POPCHAR;
    TITLE "Frequentieverdeling gereconstrueerde burgerlijke staat";
    TABLES NAREGNIS_CIVIL;
RUN;    
/*Test aantal keer dat de volledige geboortedatum ontbreekt*/
PROC SQL;
    CREATE TABLE COUNT_DatB AS
    SELECT COUNT(*) AS NUM_DatB
    FROM POPCHAR
    WHERE TRIM(NAREGNIS_DATBIRTH) = "-"
    ;
QUIT;
PROC PRINT DATA=COUNT_DatB;
    TITLE "Totaal aantal keer dat de geboortedatum volledig ontbreekt";
    VAR NUM_DatB;
RUN;    
/*Test aantal keer dat de variabele collectief gezin niet overeenstemt met de waarde 20 in NAREGNIS_RELATION*/
PROC SQL;
    CREATE TABLE COUNT_COLL AS
    SELECT COUNT(*) AS NUM_COLL
    FROM POPCHAR
    WHERE NAREGNIS_COLL NE 1 AND NAREGNIS_RELATION = 20
    ;
QUIT;
PROC PRINT DATA=COUNT_COLL;
    TITLE "Totaal aantal keer dat de waarde naregnis_relation 20 is en er geen aparte aanduiding is van collectief huishouden";
    VAR NUM_COLL;
RUN;    
PROC SQL;
    CREATE TABLE COUNT_COLL AS
    SELECT COUNT(*) AS NUM_COLL
    FROM POPCHAR
    WHERE NAREGNIS_COLL EQ 1 AND NAREGNIS_RELATION NE 20
    ;
QUIT;
PROC PRINT DATA=COUNT_COLL;
    TITLE "Totaal aantal keer dat de waarde naregnis_relation niet 20 is en er een aparte aanduiding is van collectief huishouden";
    VAR NUM_COLL;
RUN;    
/*Test aantal keer dat de variabele gezinshoofd = 1 niet is ingevuld voor de referentiepersoon*/
PROC SQL;
    CREATE TABLE COUNT_Head AS
    SELECT COUNT(*) AS NUM_Head
    FROM POPCHAR
    WHERE NAREGNIS_HEADOFHH NE 1 AND GECODEERD_INSZ = NAREGNIS_REFPERS
    ;
QUIT;
PROC PRINT DATA=COUNT_Head;
    TITLE "Totaal aantal keer dat de variabele headofhh niet 1 is voor de referentiepersoon";
    VAR NUM_Head;
RUN;    
PROC SQL;
    CREATE TABLE COUNT_Head AS
    SELECT COUNT(*) AS NUM_Head
    FROM POPCHAR
    WHERE NAREGNIS_HEADOFHH EQ 1 AND GECODEERD_INSZ <> NAREGNIS_REFPERS
    ;
QUIT;
PROC PRINT DATA=COUNT_Head;
    TITLE "Totaal aantal keer dat de variabele headofhh 1 is voor een niet referentiepersoon";
    VAR NUM_Head;
RUN;    
/*Create individual weights*/
/*steek aantal gezinsleden per gezin in de variabele NUM_HH*/
PROC SQL;
    CREATE TABLE COUNT_HH AS
    SELECT NAREGNIS_HH_ID, COUNT(*) AS NUM_HH
    FROM POPCHAR
    GROUP BY NAREGNIS_HH_ID
    ORDER BY NAREGNIS_HH_ID
    ;
QUIT;   
PROC SORT DATA=POPCHAR;
    BY NAREGNIS_HH_ID;
RUN;    
/*steek totaal aantal lijnen in POPCHAR in een variabele NUM_LINES*/
PROC SQL;
    CREATE TABLE COUNT_INDIV AS
    SELECT COUNT(*) AS NUM_INDIV
    FROM POPCHAR
    ;
QUIT; 
/*Bereken countsub en breng alle relevante gegevens samen in 1 file*/
DATA TEST;
    MERGE POPCHAR (keep=NAREGNIS_HH_ID GECODEERD_INSZ NAREGNIS_RND_SLCT REGION) COUNT_HH;
    BY NAREGNIS_HH_ID;

    COUNTSUB = NUM_HH * NAREGNIS_RND_SLCT;   
    /*selecteer enkel gevallen die random geselecteerd zijn om de som van gi's te schatten*/    

RUN;    
PROC MEANS DATA=TEST SUM NOPRINT;
    VAR COUNTSUB;
    OUTPUT OUT=OutMean SUM(COUNTSUB)=SUMCOUNT;
RUN;    
DATA TEST;
    IF _N_ EQ 1 THEN SET Outmean;
    IF _N_ EQ 1 THEN SET COUNT_INDIV;
    SET TEST;
    IF NUM_INDIV NE 0 AND NUM_INDIV NE . THEN WEIGHTS = SUMCOUNT / (NUM_HH * NUM_INDIV) ;
    KEEP GECODEERD_INSZ WEIGHTS REGION;
RUN;
PROC MEANS DATA=TEST(WHERE=(REGION=1)) SUM NOPRINT;
    VAR WEIGHTS;
    OUTPUT OUT=OutMean1 SUM(WEIGHTS)=SUMWEIGHTS_REG1;
RUN;    
PROC MEANS DATA=TEST(WHERE=(REGION=2)) SUM NOPRINT;
    VAR WEIGHTS;
    OUTPUT OUT=OutMean2 SUM(WEIGHTS)=SUMWEIGHTS_REG2;
RUN;    
PROC MEANS DATA=TEST(WHERE=(REGION=3)) SUM NOPRINT;
    VAR WEIGHTS;
    OUTPUT OUT=OutMean3 SUM(WEIGHTS)=SUMWEIGHTS_REG3;
RUN;    
DATA WEIGHTS_INDIV;
    IF _N_ EQ 1 THEN DO;
        SET Outmean1;
        SET Outmean2;
        SET Outmean3;
    END;
    SET TEST;
    /*met weights tot nu toe hoog je populatie op tot omvang van random sample
    want sumcount werd enkel berekend op basis van 100000 individuen
    Daarom moeten weights nog vermenigvuldigd worden met de factor totale populatie
    gedeeld door de som van de gewichten tot nu toe*/
    /*Aanpassing in vergelijking met vorige gewichten*/
    /*Correctie voor regio omdat gecombineerde random trekkingsprocedure niet tot volledig random trekking geleid heeft*/
    IF REGION EQ 1 THEN MIMOSIS_WEIGHT = WEIGHTS * (1068532 / SUMWEIGHTS_REG1) ;
    IF REGION EQ 2 THEN MIMOSIS_WEIGHT = WEIGHTS * (6208877 / SUMWEIGHTS_REG2) ;
    IF REGION EQ 3 THEN MIMOSIS_WEIGHT = WEIGHTS * (3475671 / SUMWEIGHTS_REG3) ;
    
    KEEP GECODEERD_INSZ MIMOSIS_WEIGHT;
RUN;
PROC MEANS DATA=WEIGHTS_INDIV mean sum max min std;
    TITLE "Verdelingsgegevens individueel gewicht";
    VAR MIMOSIS_WEIGHT;
RUN;
/*Voeg gewichten toe aan popchar*/
PROC SORT DATA=POPCHAR;
    BY GECODEERD_INSZ;
RUN;    
PROC SORT DATA=WEIGHTS_INDIV;
    BY GECODEERD_INSZ;
RUN;   
DATA POPCHAR;
    MERGE POPCHAR WEIGHTS_INDIV;
    BY GECODEERD_INSZ;
    LABEL MIMOSIS_WEIGHT = "Gewicht dat corrigeert voor niet random selectie van de observatie-eenheden";
RUN;   
/*
Het gewicht van een gezin wordt in twee stappen bepaald.
Ten eerste bepalen we het gewicht zoals beschreven in de nota die als antwoord aan Vanderhoeft 
geschreven werd. Daarin wordt het gewicht afgeleid als a) het gewicht bij random trekking dat b)
gecorrigeerd wordt voor de ongelijke manier van trekken (i.e. vermenigvuldigd met de verhouding 
populatiekans door steekproefkans)
Omdat een onderdeel van deze formule enkel geschat kan worden met een deel van de totale populatie, i;e.
de som loopt niet tot NI maar tot ni. Daarom moet er finaal nog een herschaling worden uitgevoerd.
*/
DATA TEST_START;
    SET POPCHAR(KEEP=NAREGNIS_HH_ID GECODEERD_INSZ NAREGNIS_RND_SLCT NAREGNIS_COLL REGION);
RUN;
DATA TEST_BASIS;
    SET TEST_START;
    IF  NAREGNIS_COLL EQ 1 THEN DELETE;
RUN;
/*Selecteer de gevallen (=individuen) die random getrokken werden in de eerste trekkingsronde om daarmee de Gi's te bepalen*/    
PROC SQL;
    CREATE TABLE COUNT_RANHH AS
    SELECT NAREGNIS_HH_ID, REGION, COUNT(*) AS NUM_RANHH
    FROM POPCHAR
    WHERE NAREGNIS_RND_SLCT = 1
    GROUP BY NAREGNIS_HH_ID
    ORDER BY NAREGNIS_HH_ID
    ;
QUIT;  
/*Bepaal aantal gezinsleden per gezin*/
PROC FREQ DATA=TEST_BASIS NOPRINT;
    TABLES NAREGNIS_HH_ID / OUT=OUTFREQ;
RUN;
PROC SORT DATA=OUTFREQ;
    BY NAREGNIS_HH_ID;
RUN;    
DATA TEST;
    MERGE COUNT_RANHH OUTFREQ;
    BY NAREGNIS_HH_ID;

    COUNTSUB = COUNT * NUM_RANHH; 
RUN;
/*Bereken de som van alle counts*/
PROC MEANS DATA=TEST SUM NOPRINT;
    VAR COUNTSUB;
    OUTPUT OUT=OUTMEAN SUM(COUNTSUB)=SUMCOUNT;
RUN;    
/*Bepaal het totaal aantal gezinnen in de steekproef*/
DATA NUMHH;
    SET OUTFREQ END=EOF;
    NUMHHSAMP = _N_;
    IF EOF THEN OUTPUT;
RUN;
PROC PRINT DATA=NUMHH;
    TITLE "Aantal gezinnen waarvoor een gewicht moet bepaald worden";
RUN;
/*voeg info samen*/
DATA TEST;
    IF _N_ EQ 1 THEN DO;
        SET OUTMEAN;
        SET NUMHH;
    END;        
    SET TEST; /*is file op niveau van het gezin*/
    IF NUMHHSAMP NE 0 AND NUMHHSAMP NE . THEN WEIGHTS = SUMCOUNT / (COUNT*NUMHHSAMP) ;
RUN;
/*
Tot nu toe werd het onderdeel met de som geschat op basis van gegevens die optellen
over de steekproef, terwijl het in de formule geschreven staat als een som over de totale
populatie. Om gewichten te bekomen die optellen tot de totale populatie moeten we daarom nog
herschalen op basis van de factor totale populatie gedeeld door voorheen bekomen som van gewichten
*/
PROC MEANS DATA=TEST(WHERE=(REGION=1)) SUM NOPRINT;
    VAR WEIGHTS;
    OUTPUT OUT=OutMean1 SUM(WEIGHTS)=SUMWEIGHTS_REG1;
RUN;    
PROC MEANS DATA=TEST(WHERE=(REGION=2)) SUM NOPRINT;
    VAR WEIGHTS;
    OUTPUT OUT=OutMean2 SUM(WEIGHTS)=SUMWEIGHTS_REG2;
RUN;    
PROC MEANS DATA=TEST(WHERE=(REGION=3)) SUM NOPRINT;
    VAR WEIGHTS;
    OUTPUT OUT=OutMean3 SUM(WEIGHTS)=SUMWEIGHTS_REG3;
RUN;    
DATA WEIGHTS_HH;
    IF _N_ EQ 1 THEN DO;
        SET Outmean1;
        SET Outmean2;
        SET Outmean3;
    END;
    SET TEST;

    /*Aanpassing in vergelijking met vorige gewichten*/
    /*Correctie voor regio omdat gecombineerde random trekkingsprocedure niet tot volledig random trekking geleid heeft*/
    IF REGION EQ 1 THEN HH_Weights = WEIGHTS * ( 511458 / SUMWEIGHTS_REG1) ;    
    IF REGION EQ 2 THEN HH_Weights = WEIGHTS * (2601266 / SUMWEIGHTS_REG2) ;    
    IF REGION EQ 3 THEN HH_Weights = WEIGHTS * (1493820 / SUMWEIGHTS_REG3) ;    

    KEEP NAREGNIS_HH_ID HH_Weights;
RUN;
PROC MEANS DATA=WEIGHTS_HH MEAN SUM MAX MIN STD;
    TITLE "Verdelingsgegevens van gezinsgewicht";
    VAR HH_Weights;
RUN;    
/*Voeg gewichten toe aan popchar*/
PROC SORT DATA=POPCHAR;
    BY NAREGNIS_HH_ID;
RUN;    
PROC SORT DATA=WEIGHTS_HH;
    BY NAREGNIS_HH_ID;
RUN;   
DATA LIBW.POPCHAR_2009;

    MERGE POPCHAR WEIGHTS_HH;
    BY NAREGNIS_HH_ID;

    IF HH_Weights EQ . THEN  HH_Weights = 0;

    LABEL HH_Weights            = "Gewicht van het privaat sociologisch gezin waartoe het individu behoort (nodig om gegevens op te hogen tot het niveau van huishoudpopulatie)";
    LABEL NAREGNIS_HH_ID        = "Geanonimiseerd identificatienummer van het gezin waartoe het individu behoort";
    LABEL NAREGNIS_HEADOFHH     = "Aanduiding of het individu op 1 januari 2009 gezinshoofd is van het gezin waartoe het individu behoort";
    LABEL NAREGNIS_DATBIRTH     = "Geboortedatum van het individu in jaar en maand";
    LABEL NAREGNIS_REFPERS      = "Geanonimiseerd identificatienummer van de referentiepersoon van het gezin waartoe het individu behoort";
    LABEL NAREGNIS_RELATION     = "Verband tussen het individu en het huishoudhoofd op 1 januari 2009";
    LABEL NAREGNIS_SEX          = "Geslacht van het individu op 1 januari 2009";
    LABEL NAREGNIS_COMMUNIT     = "NIS gemeentecode van de woonplaats waar het individu op 1 januari 2009 woonde";
    LABEL NAREGNIS_TYPEHH       = "Typologie van het gezin waartoe het individu behoort op 1 januari 2009";
    LABEL NAREGNIS_COLL         = "Aanduiding of het gezin waartoe het individu op 1 januari 2009 behoort een collectief gezin is";
    LABEL NAREGNIS_LIPRO        = "Typologie van het individu op basis van eigenschappen van het gezin waartoe het individu behoort op 1 januari 2009";
    LABEL NAREGNIS_RND_SLCT     = "Aanduiding of het individu geselecteerd werd bij het trekken van de steekproef (= ja of nee)";
    LABEL NAREGNIS_CIVIL        = "Burgerlijke staat van het individu op 1 januari 2009";
    LABEL GECODEERD_INSZ        = "Geanonimiseerd identificatienummer van het individu";
    
    DROP REGION PROV;
RUN;   
PROC CONTENTS DATA=LIBW.POPCHAR_2009;
RUN;
PROC PRINT DATA=LIBW.POPCHAR_2009(WHERE=(HH_Weights EQ . OR MIMOSIS_WEIGHT EQ .));
RUN;
/*einde programma*/
PROC PRINTTO LOG=LOG PRINT=PRINT;
RUN;
